Module userdata_trait

Module userdata_trait 

Structs

OpaqueUserData
Wraps any T: 'static as an opaque Lua userdata.
RefUserData
A userdata wrapper that holds a raw pointer to an external T: UserDataTrait.

Enums

UdValue
Intermediate value type for userdata field/method returns.

Traits

LuaEnum
Trait for Rust enums that can be exported to Lua as a table of constants.
LuaMethodProvider
Blanket trait providing a default no-op method lookup.
LuaRegistrable
Trait for types that can be registered with Lua via register_type_of::<T>.
LuaStaticMethodProvider
Blanket trait providing a default empty static methods list.
UserDataTrait
Describes how a userdata type can be accessed from Lua.

Functions

lua_value_to_udvalue
Convert a LuaValue to a UdValue.
udvalue_to_lua_value
Convert a UdValue to a LuaValue.