LuaMethodProvider

Trait LuaMethodProvider 

pub trait LuaMethodProvider {
    // Provided method
    fn __lua_lookup_method(_key: &str) -> Option<CFunction> { ... }
}
Blanket trait providing a default no-op method lookup.

When #[lua_methods] attribute macro is used on an impl block, it generates an inherent __lua_lookup_method function on the type that shadows this trait’s default. The derive macro’s get_field calls Self::__lua_lookup_method(key) which resolves to the inherent method (if defined) or falls back to this default.

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors