AsyncThread

Struct AsyncThread 

pub struct AsyncThread { /* private fields */ }
Wraps a Lua coroutine as a Rust Future.

Drives the coroutine to completion by repeatedly resuming it and polling any pending async futures. The coroutine’s LuaState is rooted in the VM registry to prevent garbage collection while the AsyncThread is alive.

Safety

  • AsyncThread is !Send and !Sync (contains raw pointer to LuaVM).
  • Must be polled from the same thread that created it.
  • The LuaVM must outlive the AsyncThread.

Example

let async_thread = vm.create_async_thread(chunk)?;
let results = async_thread.await?;