Chunk

Struct Chunk 

pub struct Chunk<'lua> { /* private fields */ }
Builder returned by Lua::load, similar to mlua::Chunk.

Implementations

Source

impl<'lua> Chunk<'lua>

pub fn set_name(self, name: impl Into<String>) -> Self

Set a chunk name used in diagnostics.

pub fn into_function(self) -> LuaResult<Function>

Compile the chunk and return it as a callable function handle.

pub fn exec(self) -> LuaResult<()>

Execute the chunk and discard returned values.

pub async fn exec_async(self) -> LuaResult<()>

Execute the chunk asynchronously and discard returned values.

pub fn eval<R: FromLua>(self) -> LuaResult<R>

Execute the chunk and convert the first return value.

pub async fn eval_async<R: FromLua>(self) -> LuaResult<R>

Execute the chunk asynchronously and convert the first return value.

pub fn eval_multi<R: FromLuaMulti>(self) -> LuaResult<R>

Execute the chunk and convert all returned values.

pub async fn eval_multi_async<R: FromLuaMulti>(self) -> LuaResult<R>

Execute the chunk asynchronously and convert all returned values.

pub fn call<A: IntoLua, R: FromLuaMulti>(self, args: A) -> LuaResult<R>

Compile the chunk and call it with Rust arguments.

pub async fn call_async<A: IntoLua, R: FromLuaMulti>( self, args: A, ) -> LuaResult<R>

Compile the chunk and call it asynchronously with Rust arguments.

pub fn call1<A: IntoLua, R: FromLua>(self, args: A) -> LuaResult<R>

Compile the chunk and call it, converting only the first return value.

pub async fn call1_async<A: IntoLua, R: FromLua>(self, args: A) -> LuaResult<R>

Compile the chunk and call it asynchronously, converting only the first return value.