Structs
- Opaque
User Data - Wraps any
T: 'staticas an opaque Lua userdata. - RefUser
Data - A userdata wrapper that holds a raw pointer to an external
T: UserDataTrait.
Enums
- UdValue
- Intermediate value type for userdata field/method returns.
Traits
- LuaEnum
- Trait for Rust enums that can be exported to Lua as a table of constants.
- LuaMethod
Provider - Blanket trait providing a default no-op method lookup.
- LuaRegistrable
- Trait for types that can be registered with Lua via
register_type_of::<T>. - LuaStatic
Method Provider - Blanket trait providing a default empty static methods list.
- User
Data Trait - Describes how a userdata type can be accessed from Lua.
Functions
- lua_
value_ to_ udvalue - Convert a
LuaValueto aUdValue. - udvalue_
to_ lua_ value - Convert a
UdValueto aLuaValue.