pub struct AsyncThread { /* private fields */ }Expand description
Wraps a Lua coroutine as a Rust Future.
Drives the coroutine to completion by repeatedly resuming it and polling
any pending async futures. The coroutine’s LuaState is rooted in the
VM registry to prevent garbage collection while the AsyncThread is alive.
Safety
AsyncThreadis!Sendand!Sync(contains raw pointer toLuaVM).- Must be polled from the same thread that created it.
- The
LuaVMmust outlive theAsyncThread.
Example
ⓘ
let async_thread = vm.create_async_thread(chunk)?;
let results = async_thread.await?;Trait Implementations
Sourceimpl Drop for AsyncThread
impl Drop for AsyncThread
Sourceimpl Future for AsyncThread
impl Future for AsyncThread